REGIONS = {u'ad': u'\u0531\u0576\u0564\u0578\u057c\u057c\u0561',
 u'ae': u'\u0544.\u0531.\u0537.',
 u'af': u'\u0531\u0586\u0572\u0561\u0576\u057d\u057f\u0561\u0576',
 u'ag': u'\u0531\u0576\u057f\u056b\u0563\u0578\u0582\u0561 \u0587 \u0532\u0561\u0580\u0562\u0578\u0582\u0564\u0561',
 u'ai': u'\u0531\u0576\u0563\u0578\u0582\u056b\u056c\u0561',
 u'al': u'\u0531\u056c\u0562\u0561\u0576\u056b\u0561',
 u'am': u'\u0540\u0561\u0575\u0561\u057d\u057f\u0561\u0576',
 u'an': u'\u0546\u056b\u0564\u0565\u057c\u056c\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u0531\u0576\u057f\u056b\u056c\u0565\u0561\u0576\u0565\u0580',
 u'ao': u'\u0531\u0576\u0563\u0578\u056c\u0561',
 u'aq': u'\u0531\u0576\u057f\u0561\u0580\u056f\u057f\u056b\u056f\u0561',
 u'ar': u'\u0531\u0580\u0563\u0565\u0576\u057f\u056b\u0576\u0561',
 u'as': u'\u0531\u0574\u0565\u0580\u056b\u056f\u0575\u0561\u0576 \u054d\u0561\u0574\u0578\u0561',
 u'at': u'\u0531\u057e\u057d\u057f\u0580\u056b\u0561',
 u'au': u'\u0531\u057e\u057d\u057f\u0580\u0561\u056c\u056b\u0561',
 u'aw': u'\u0531\u0580\u0578\u0582\u0562\u0561',
 u'ax': u'\u0531\u056c\u0561\u0576\u0564\u0561\u056f\u0561\u0576 \u053f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'az': u'\u0531\u0564\u0580\u0562\u0565\u057b\u0561\u0576',
 u'ba': u'\u0532\u0578\u057d\u0576\u056b\u0561 \u0587 \u0540\u0565\u0580\u0581\u0565\u0563\u0578\u057e\u056b\u0576\u0561',
 u'bb': u'\u0532\u0561\u0580\u0562\u0562\u0561\u0564\u0578\u057d',
 u'bd': u'\u0532\u0561\u0576\u0563\u056c\u0561\u0564\u0565\u0577',
 u'be': u'\u0532\u0565\u056c\u0563\u056b\u0561',
 u'bf': u'\u0532\u0578\u0582\u057c\u056f\u056b\u0576\u0561 \u0556\u0561\u057d\u0578',
 u'bg': u'\u0532\u0578\u0582\u056c\u0572\u0561\u0580\u056b\u0561',
 u'bh': u'\u0532\u0561\u0570\u0580\u0561\u056b\u0576',
 u'bi': u'\u0532\u0578\u0582\u0580\u0578\u0582\u0576\u0564\u056b',
 u'bj': u'\u0532\u0565\u0576\u056b\u0576',
 u'bl': u'\u054d\u0561\u056b\u0576\u0569 \u0532\u0561\u057c\u0569\xe9lemy',
 u'bm': u'\u0532\u0565\u0580\u0574\u0578\u0582\u0564\u0561',
 u'bn': u'\u0532\u0580\u0578\u0582\u0576\u0565\u056b \u054d\u0578\u0582\u056c\u0569\u0561\u0576\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
 u'bo': u'\u0532\u0578\u056c\u056b\u057e\u056b\u0561',
 u'br': u'\u0532\u0580\u0561\u057d\u056b\u056c\u056b\u0561',
 u'bs': u'\u0532\u0561\u0570\u0561\u0574\u0561\u057d',
 u'bt': u'\u0532\u0570\u0578\u0582\u057f\u0561\u0576',
 u'bv': u'\u0532\u0578\u0582\u057e\u0565\u057f \u056f\u0572\u0566\u056b',
 u'bw': u'\u0532\u0578\u0569\u057d\u057e\u0561\u0576\u0561',
 u'by': u'\u0532\u0565\u056c\u0561\u057c\u0578\u0582\u057d',
 u'bz': u'\u0532\u0565\u056c\u056b\u0566\u0565',
 u'ca': u'\u053f\u0561\u0576\u0561\u0564\u0561',
 u'cc': u'\u056f\u0578\u056f\u0578\u057d\u0561\u0575\u056b\u0576 (\u056f\u056b\u056b\u056c\u056b\u0576\u0563) \u053f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'cd': u'\u053f\u0578\u0576\u0563\u0578',
 u'cf': u'\u053f\u0565\u0576\u057f\u0580\u0578\u0576\u0561\u056f\u0561\u0576 \u0531\u0586\u0580\u056b\u056f\u0575\u0561\u0576 \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
 u'cg': u'\u053f\u0578\u0576\u0563\u0578 \u0562\u057c\u0561\u0566\u0561\u057e\u056b\u056c\u056c\u0565',
 u'ch': u'\u0547\u057e\u0565\u0575\u0581\u0561\u0580\u056b\u0561',
 u'ci': u'\u053b\u057e\u0578\u0580\u056b \u053f\u0578\u057d\u057f',
 u'ck': u'\u0554\u0578\u0582\u056f\u056b \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'cl': u'\u0549\u056b\u056c\u056b',
 u'cm': u'\u053f\u0561\u0574\u0565\u057c\u0578\u0582\u0576',
 u'cn': u'\u0549\u056b\u0576\u0561\u057d\u057f\u0561\u0576',
 u'co': u'\u053f\u0578\u056c\u0578\u0582\u0574\u0562\u056b\u0561',
 u'cr': u'\u053f\u0578\u057d\u057f\u0561 \u054c\u056b\u056f\u0561',
 u'cu': u'\u053f\u0578\u0582\u0562\u0561',
 u'cv': u'\u053f\u0561\u0562\u0565-\u057e\u0565\u0580\u0564\u0565',
 u'cx': u'\u054d\u0578\u0582\u0580\u0562 \u053e\u0576\u0576\u0564\u0575\u0561\u0576 \u056f\u0572\u0566\u056b',
 u'cy': u'\u053f\u056b\u057a\u0580\u0578\u057d',
 u'cz': u'\u0549\u0565\u056d\u056b\u0561\u0575\u056b \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
 u'de': u'\u0533\u0565\u0580\u0574\u0561\u0576\u056b\u0561',
 u'dj': u'\u054b\u056b\u0562\u0578\u0582\u057f\u056b',
 u'dk': u'\u0534\u0561\u0576\u056b\u0561',
 u'dm': u'\u0534\u0578\u0574\u056b\u0576\u056b\u056f\u0561',
 u'do': u'\u0534\u0578\u0574\u056b\u0576\u056b\u056f\u0575\u0561\u0576 \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
 u'dz': u'\u0531\u056c\u056a\u056b\u0580',
 u'ec': u'\u0535\u056f\u057e\u0561\u0564\u0578\u0580',
 u'ee': u'\u0537\u057d\u057f\u0578\u0576\u056b\u0561',
 u'eg': u'\u0535\u0563\u056b\u057a\u057f\u0578\u057d',
 u'eh': u'\u0531\u0580\u0587\u0574\u057f\u0575\u0561\u0576 \u054d\u0561\u0570\u0561\u0580\u0561',
 u'er': u'\u0537\u0580\u056b\u057f\u0580\u0565\u0561',
 u'es': u'\u053b\u057d\u057a\u0561\u0576\u056b\u0561',
 u'et': u'\u0537\u0569\u056b\u0578\u057a\u056b\u0561',
 u'fi': u'\u0556\u056b\u0576\u056c\u0561\u0576\u0564\u056b\u0561',
 u'fj': u'\u0586\u056b\u057b\u056b',
 u'fk': u'\u0586\u0561\u056c\u056f\u056c\u0561\u0576\u0564\u0575\u0561\u0576 (\u0544\u0561\u056c\u057e\u056b\u0576\u0575\u0561\u0576) \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'fm': u'\u0544\u056b\u056f\u0580\u0578\u0576\u0565\u0566\u056b\u0561',
 u'fo': u'\u0556\u0561\u057c\u0565\u0580\u0575\u0561\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'fr': u'\u0556\u0580\u0561\u0576\u057d\u056b\u0561',
 u'ga': u'\u0533\u0561\u0562\u0578\u0576',
 u'gb': u'\u0544\u0565\u056e \u0532\u0580\u056b\u057f\u0561\u0576\u056b\u0561',
 u'gd': u'\u0533\u0580\u0565\u0576\u0561\u0564\u0561',
 u'ge': u'\u054e\u0580\u0561\u057d\u057f\u0561\u0576',
 u'gf': u'\u0586\u0580\u0561\u0576\u057d\u056b\u0561\u056f\u0561\u0576 \u0533\u057e\u056b\u0576\u0565\u0561',
 u'gg': u'\u0533\u0565\u057c\u0576\u057d\u056b',
 u'gh': u'\u0533\u0561\u0576\u0561',
 u'gi': u'\u0533\u056b\u0562\u0580\u0561\u056c\u057f\u0561\u0580',
 u'gl': u'\u0533\u0580\u0565\u0576\u056c\u0561\u0576\u0564\u056b\u0561',
 u'gm': u'\u0533\u0561\u0574\u0562\u056b\u0561',
 u'gn': u'\u0533\u057e\u056b\u0576\u0565\u0561',
 u'gp': u'\u0533\u057e\u0561\u0564\u0565\u056c\u0578\u0582\u057a',
 u'gq': u'\u0537\u056f\u057e\u0561\u057f\u0578\u0580\u056b\u0561\u056c \u0533\u057e\u056b\u0576\u0565\u0561',
 u'gr': u'\u0540\u0578\u0582\u0576\u0561\u057d\u057f\u0561\u0576',
 u'gs': u'\u0540\u0575\u0578\u0582\u057d\u056b\u057d\u0561\u0575\u056b\u0576 \u054b\u0578\u0580\u057b\u056b\u0561 \u0587 \u0540\u0575\u0578\u0582\u057d\u056b\u057d\u0561\u0575\u056b\u0576 \u054d\u0561\u0576\u0564\u057e\u056b\u0579\u0575\u0561\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'gt': u'\u0533\u057e\u0561\u057f\u0565\u0574\u0561\u056c\u0561',
 u'gu': u'\u0533\u0578\u0582\u0561\u0574',
 u'gw': u'\u0533\u057e\u056b\u0576\u0565\u0561-\u0532\u056b\u057d\u0561\u0578\u0582',
 u'gy': u'\u0533\u0561\u0575\u0561\u0576\u0561',
 u'hk': u'\u0540\u0578\u0576\u0563 \u053f\u0578\u0576\u0563',
 u'hm': u'\u0540\u0565\u0580\u0564\u056b \u056f\u0572\u0566\u056b \u0587 \u0544\u0561\u056f\u0564\u0578\u0576\u0561\u056c\u0564\u056b \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'hn': u'\u0540\u0578\u0576\u0564\u0578\u0582\u0580\u0561\u057d',
 u'hr': u'\u053d\u0578\u0580\u057e\u0561\u0569\u056b\u0561',
 u'ht': u'\u0540\u0561\u056b\u0569\u056b',
 u'hu': u'\u0540\u0578\u0582\u0576\u0563\u0561\u0580\u056b\u0561',
 u'id': u'\u053b\u0576\u0564\u0578\u0576\u0565\u0566\u056b\u0561',
 u'ie': u'\u053b\u057c\u056c\u0561\u0576\u0564\u056b\u0561',
 u'il': u'\u053b\u057d\u0580\u0561\u0575\u0565\u056c',
 u'im': u'\u0544\u0565\u0576 \u053f\u0572\u0566\u056b',
 u'in': u'\u0540\u0576\u0564\u056f\u0561\u057d\u057f\u0561\u0576',
 u'io': u'\u0540\u0576\u0564\u056f\u0561\u056f\u0561\u0576 \u0585\u057e\u056f\u056b\u0561\u0576\u0578\u057d\u056b \u0532\u0580\u056b\u057f\u0561\u0576\u0561\u056f\u0561\u0576 \u057f\u0561\u0580\u0561\u056e\u0561\u0577\u0580\u057b\u0561\u0576',
 u'iq': u'\u053b\u0580\u0561\u0584',
 u'ir': u'\u053b\u0580\u0561\u0576',
 u'is': u'\u053b\u057d\u056c\u0561\u0576\u0564\u056b\u0561',
 u'it': u'\u053b\u057f\u0561\u056c\u056b\u0561',
 u'je': u'\u054b\u0565\u0580\u057d\u056b',
 u'jm': u'\u054b\u0561\u0574\u0561\u0575\u056f\u0561',
 u'jo': u'\u0540\u0578\u0580\u0564\u0561\u0576\u0561\u0576',
 u'jp': u'\u0543\u0561\u057a\u0578\u0576\u056b\u0561',
 u'ke': u'\u053f\u0565\u0576\u0575\u0561',
 u'kg': u'\u0542\u0580\u0572\u0566\u057d\u057f\u0561\u0576',
 u'kh': u'\u053f\u0561\u0574\u0562\u0578\u0564\u056b\u0561',
 u'ki': u'\u053f\u056b\u0580\u056b\u0562\u0561\u0569',
 u'km': u'\u053f\u0561\u0574\u0578\u057d',
 u'kn': u'\u054d\u0561\u056b\u0576\u057f-\u056f\u056b\u057f\u057d \u0587 \u0546\u0565\u057e\u056b\u057d',
 u'kp': u'\u0540\u0575\u0578\u0582\u057d. \u053f\u0578\u0580\u0565\u0561',
 u'kr': u'\u0540\u0561\u0580\u0561\u057e. \u053f\u0578\u0580\u0565\u0561',
 u'kw': u'\u053f\u0578\u0582\u057e\u0565\u0575\u0569',
 u'ky': u'\u053f\u0561\u0575\u0574\u0561\u0576\u0575\u0561\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'kz': u'\u0542\u0561\u0566\u0561\u056d\u057d\u057f\u0561\u0576',
 u'la': u'\u053c\u0561\u0578\u057d',
 u'lb': u'\u053c\u056b\u0562\u0561\u0576\u0561\u0576',
 u'lc': u'\u054d\u0561\u0576\u057f \u053c\u0578\u0582\u057d\u056b\u0561',
 u'li': u'\u053c\u056b\u056d\u057f\u0565\u0576\u0577\u057f\u0561\u0575\u0576',
 u'lk': u'\u0547\u0580\u056b \u053c\u0561\u0576\u056f\u0561',
 u'lr': u'\u053c\u056b\u0562\u0565\u0580\u056b\u0561',
 u'ls': u'\u053c\u0565\u057d\u0578\u0569\u0578',
 u'lt': u'\u053c\u056b\u057f\u057e\u0561',
 u'lu': u'\u053c\u0578\u0582\u0584\u057d\u0565\u0574\u0562\u0578\u0582\u0580\u0563',
 u'lv': u'\u053c\u0561\u057f\u057e\u056b\u0561',
 u'ly': u'\u053c\u056b\u0562\u056b\u0561',
 u'ma': u'\u0544\u0561\u0580\u0578\u0584\u0584\u0578',
 u'mc': u'\u0544\u0578\u0576\u0561\u056f\u0578',
 u'md': u'\u0544\u0578\u056c\u0564\u0561\u057e\u0561\u056f\u0561\u0576 \u0540\u0561\u0576\u0580\u0561\u057a\u0565\u057f\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
 u'me': u'\u0544\u0578\u0576\u057f\u0565\u0576\u0565\u0563\u0580\u0578',
 u'mf': u'Saint Martin',
 u'mg': u'\u0544\u0561\u0564\u0561\u0563\u0561\u057d\u056f\u0561\u0580',
 u'mh': u'\u0544\u0561\u0580\u0577\u0561\u056c\u0575\u0561\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'mk': u'\u0544\u0561\u056f\u0565\u0564\u0578\u0576\u056b\u0561, \u0546.\u0540.\u0540.',
 u'ml': u'\u0544\u0561\u056c\u056b',
 u'mm': u'\u0544\u0575\u0561\u0576\u0574\u0561\u0580',
 u'mn': u'\u0544\u0578\u0576\u0572\u0578\u056c\u056b\u0561',
 u'mo': u'\u0544\u0561\u0584\u0561\u0578',
 u'mp': u'\u0540\u0575\u0578\u0582\u057d\u056b\u057d\u0561\u0575\u056b\u0576 \u0544\u0561\u0580\u0561\u0576\u0576\u0561 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'mq': u'\u0544\u0561\u0580\u057f\u056b\u0576\u056b\u056f\u0561',
 u'mr': u'\u0544\u0561\u0578\u0582\u0580\u056b\u057f\u0561\u0576\u056b\u0561',
 u'ms': u'\u0544\u0578\u0576\u057f\u057d\u0565\u0580\u0580\u0561\u057f',
 u'mt': u'\u0544\u0561\u056c\u0569\u0561',
 u'mu': u'\u0544\u0561\u0578\u0582\u0580\u056b\u057f\u056b\u0578\u0582\u057d',
 u'mv': u'\u0544\u0561\u057e\u0580\u056b\u057f\u056b\u0578\u0582\u057d',
 u'mw': u'\u0544\u0561\u056c\u0561\u057e\u056b',
 u'mx': u'\u0544\u0565\u0584\u057d\u056b\u056f\u0561',
 u'my': u'\u0544\u0561\u056c\u0561\u0566\u056b\u0561',
 u'mz': u'\u0544\u0578\u0566\u0561\u0574\u0562\u056b\u056f',
 u'na': u'\u0546\u0561\u0574\u056b\u0562\u056b\u0561',
 u'nc': u'\u0546\u0578\u0580 \u053f\u0561\u056c\u0565\u0564\u0578\u0576\u056b\u0561',
 u'ne': u'\u0546\u056b\u0563\u0565\u0580',
 u'nf': u'\u0546\u0578\u0580\u0586\u0578\u056c\u056f \u056f\u0572\u0566\u056b',
 u'ng': u'\u0546\u056b\u0563\u0565\u0580\u056b\u0561',
 u'ni': u'\u0546\u056b\u056f\u0561\u0580\u0561\u0563\u0578\u0582\u0561',
 u'nl': u'\u0546\u056b\u0564\u0565\u0580\u056c\u0561\u0576\u0564\u0576\u0565\u0580',
 u'no': u'\u0546\u0578\u0580\u057e\u0578\u0563\u056b\u0561',
 u'np': u'\u0546\u0565\u057a\u0561\u056c',
 u'nr': u'\u0546\u0561\u0578\u0582\u057c\u0578\u0582',
 u'nu': u'\u0546\u056b\u0578\u0582\u0565',
 u'nz': u'\u0546\u0578\u0580 \u0536\u0565\u056c\u0561\u0576\u0564\u056b\u0561',
 u'om': u'\u0555\u0574\u0561\u0576',
 u'pa': u'\u054a\u0561\u0576\u0561\u0574\u0561',
 u'pe': u'\u054a\u0565\u0580\u0578\u0582',
 u'pf': u'\u0556\u0580\u0561\u0576\u057d\u056b\u0561\u056f\u0561\u0576 \u054a\u0578\u056c\u056b\u0576\u0565\u0566\u056b\u0561',
 u'pg': u'\u054a\u0561\u057a\u0578\u0582\u0561 \u0546\u0578\u0580 \u0533\u057e\u056b\u0576\u0565\u0561',
 u'ph': u'\u0556\u056b\u056c\u056b\u057a\u056b\u0576\u0576\u0565\u0580',
 u'pk': u'\u054a\u0561\u056f\u056b\u057d\u057f\u0561\u0576',
 u'pl': u'\u053c\u0565\u0570\u0561\u057d\u057f\u0561\u0576',
 u'pm': u'\u054d\u0565\u0576\u057f \u054a\u056b\u0565\u057c \u0587 \u0544\u056b\u056f\u0565\u056c\u057d\u0578\u0576',
 u'pn': u'\u054a\u056b\u057f\u056f\u0565\u057c\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'pr': u'\u054a\u0578\u0582\u0565\u0580\u057f\u0578 \u054c\u056b\u056f\u0578',
 u'ps': u'\u054a\u0561\u056c\u0565\u057d\u057f\u056b\u0576\u0575\u0561\u0576 \u0585\u056f\u0578\u0582\u057a\u0561\u0581\u057e\u0561\u056e \u0577\u0580\u057b\u0561\u0576',
 u'pt': u'\u054a\u0578\u0580\u057f\u0578\u0582\u0563\u0561\u056c',
 u'pw': u'\u054a\u0561\u056c\u0561\u0578\u0582',
 u'py': u'\u054a\u0561\u0580\u0561\u0563\u057e\u0561\u0575',
 u'qa': u'\u0554\u0561\u0569\u0561\u0580',
 u're': u'\u054c\u0565\u0575\u0578\u0582\u0576\u056b\u0578\u0576',
 u'ro': u'\u054c\u0578\u0582\u0574\u056b\u0576\u056b\u0561',
 u'rs': u'\u054d\u0565\u0580\u0562\u056b\u0561',
 u'ru': u'\u054c\u0578\u0582\u057d\u0561\u057d\u057f\u0561\u0576\u056b \u0534\u0561\u0577\u0576\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
 u'rw': u'\u054c\u0578\u0582\u0561\u0576\u0564\u0561',
 u'sa': u'\u054d\u0561\u0582\u0564\u0575\u0561\u0576 \u0531\u0580\u0561\u0562\u056b\u0561',
 u'sb': u'\u054d\u0578\u056c\u0578\u0574\u0578\u0576\u0575\u0561\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'sc': u'\u054d\u0565\u056b\u0579\u0565\u056c\u056c\u0565\u057d',
 u'sd': u'\u054d\u0578\u0582\u0564\u0561\u0576',
 u'se': u'\u0547\u057e\u0565\u0564\u056b\u0561',
 u'sg': u'\u054d\u056b\u0576\u0563\u0561\u057a\u0578\u0582\u0580',
 u'sh': u'\u054d. \u0540\u0565\u056c\u0565\u0576\u0561',
 u'si': u'\u054d\u056c\u0578\u057e\u0565\u0576\u056b\u0561',
 u'sj': u'\u054d\u057e\u0561\u056c\u0562\u0561\u0580\u0564 \u0587 \u054b\u0561\u0576 \u0544\u0561\u0575\u0565\u0580',
 u'sk': u'\u054d\u056c\u0578\u057e\u0561\u056f\u056b\u0561',
 u'sl': u'\u054d\u056b\u0565\u0580\u0580\u0561 \u053c\u0565\u0578\u0576\u0565',
 u'sm': u'\u054d\u0561\u0576 \u0544\u0561\u0580\u056b\u0576\u0578',
 u'sn': u'\u054d\u0565\u0576\u0565\u0563\u0561\u056c',
 u'so': u'\u054d\u0578\u0574\u0561\u056c\u056b',
 u'sr': u'\u054d\u0578\u0582\u0580\u056b\u0576\u0561\u0574',
 u'st': u'\u054d\u0561\u0576-\u054f\u0578\u0574\u0565 \u0587 \u054a\u0580\u056b\u0576\u057d\u056b\u057a\u056b',
 u'sv': u'\u0537\u056c \u054d\u0561\u056c\u057e\u0561\u0564\u0578\u0580',
 u'sy': u'\u054d\u056b\u0580\u056b\u0561',
 u'sz': u'\u054d\u057e\u0561\u0566\u056b\u056c\u0565\u0576\u0564',
 u'tc': u'\u0539\u0578\u0582\u0580\u0584 \u0587 \u053f\u0561\u056b\u056f\u0578\u057d \u056f\u0566\u0572\u056b\u0576\u0565\u0580',
 u'td': u'\u0549\u0561\u0564',
 u'tf': u'\u0556\u0580\u0561\u0576\u057d\u056b\u0561\u0575\u056b \u0570\u0575\u0578\u0582\u057d\u056b\u057d\u0561\u0575\u056b\u0576 \u057f\u0561\u0580\u0561\u056e\u0584\u0576\u0565\u0580',
 u'tg': u'\u054f\u0578\u0563\u0578',
 u'th': u'\u0539\u0561\u0575\u056c\u0561\u0576\u0564',
 u'tj': u'\u054f\u0561\u057b\u056b\u056f\u057d\u057f\u0561\u0576',
 u'tk': u'\u054f\u0578\u056f\u0565\u056c\u0561\u0578\u0582',
 u'tl': u'\u054f\u056b\u0574\u0578\u057c-\u053c\u0565\u057d\u057f',
 u'tm': u'\u0539\u0578\u0582\u0580\u0584\u0574\u0565\u0576\u057d\u057f\u0561\u0576',
 u'tn': u'\u0539\u0578\u0582\u0576\u0576\u056b\u057d',
 u'to': u'\u054f\u0578\u0576\u0563\u0561',
 u'tr': u'\u0539\u0578\u0582\u0580\u0584\u056b\u0561',
 u'tt': u'\u054f\u0580\u056b\u0576\u056b\u0576\u0564\u0561\u0564 \u0587 \u054f\u0578\u0562\u0561\u0563\u0578',
 u'tv': u'\u054f\u0578\u0582\u057e\u0561\u056c\u0578\u0582',
 u'tw': u'\u0539\u0561\u0575\u057e\u0561\u0576',
 u'tz': u'\u054f\u0561\u0576\u0566\u0561\u0576\u056b\u0561',
 u'ua': u'\u0548\u0582\u056f\u0580\u0561\u056b\u0576\u0561',
 u'ug': u'\u0548\u0582\u0563\u0561\u0576\u0564\u0561',
 u'um': u'\u0531\u0544\u0546 \u053d\u0561\u0572\u0561\u0572\u0578\u057e\u056f\u056b\u0561\u0576\u0578\u057d\u0575\u0561\u0576 \u0570\u0565\u057c\u0578\u0582 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'us': u'\u0544\u056b\u0561\u0581\u0575\u0561\u056c \u0546\u0561\u0570\u0561\u0576\u0563\u0576\u0565\u0580',
 u'uy': u'\u0548\u0582\u0580\u0578\u0582\u0563\u057e\u0561\u0575',
 u'uz': u'\u0548\u0582\u0566\u0562\u0565\u056f\u056b\u057d\u057f\u0561\u0576',
 u'va': u'\u054e\u0561\u057f\u056b\u056f\u0561\u0576',
 u'vc': u'\u054d\u0565\u0576\u057f \u054e\u056b\u0576\u057d\u0565\u0576\u057f \u0587 \u0533\u0580\u0565\u0576\u0561\u0564\u056b\u0576\u0576\u0565\u0580',
 u've': u'\u054e\u0565\u0576\u0565\u057d\u0578\u0582\u0565\u056c\u056c\u0561',
 u'vg': u'\u0532\u0580\u056b\u057f\u0561\u0576\u0561\u056f\u0561\u0576 \u054e\u056b\u057c\u057b\u056b\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'vi': u'\u0531\u0544\u0546 \u054e\u056b\u057c\u057b\u056b\u0576 \u056f\u0572\u0566\u056b\u0576\u0565\u0580',
 u'vn': u'\u054e\u056b\u0565\u057f\u0576\u0561\u0574',
 u'vu': u'\u054e\u0561\u0576\u0578\u0582\u0561\u057f\u0578\u0582',
 u'wf': u'\u054e\u0578\u056c\u056b\u057d \u0587 \u0556\u0578\u0582\u057f\u0578\u0582\u0576\u0561',
 u'ws': u'\u054d\u0561\u0574\u0578\u0561',
 u'ye': u'\u0545\u0565\u0574\u0565\u0576',
 u'yt': u'\u0544\u0561\u0575\u0578\u057f\u057f',
 u'za': u'\u0540\u0561\u0580\u0561\u057e\u0561\u0575\u056b\u0576 \u0531\u0586\u0580\u056b\u056f\u0561',
 u'zm': u'\u0536\u0561\u0574\u0562\u056b\u0561',
 u'zw': u'\u0536\u056b\u0574\u0562\u0561\u0562\u057e\u0565'}